==> sql-ledger_2.2.6.orig.tar.gz: sql-ledger/sql/Hungary-chart.sql <==
--Hungarian chart of accounts 
-- Magyar fknyvi szmlk, amelyek csak pldaknt szolglnak
--
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1140','Irodai eszkzk','A','A','','114');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1199','Irodai eszkzk CS','A','A','','119');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2610','ruk ','A','A','IC','261');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3110','Vevk','A','A','AR','311');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3111','Klfldi vevk','A','A','AR','311');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3810','Pnztr 1','A','A','AR_paid:AP_paid','381');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3811','Pnztr 2','A','A','AR_paid:AP_paid','381');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3840','Bank 1','A','A','AR_paid:AP_paid','384');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3841','Bank 2','A','A','AR_paid:AP_paid','384');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4540','Belfldi Szlltk','A','L','AP','454');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4541','Klfldi szlltk','A','L','AP','454');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4660','Visszaignyelhet FA 25%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4661','Visszaignyelhet FA 12%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4662','Visszaignyelhet FA 5%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4663','Visszaignyelhet FA admentes','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4670','Fizetend FA 25%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4671','Fizetend FA 15%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4672','Fizetend FA 5%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4673','Fizetend FA admentes','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5200','Brleti dj','A','E','AP_amount','520');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5210','Telefon','A','E','AP_amount','521');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5990','Kltsgek','A','E','IC_expense','599');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8140','Eladott ruk beszerzsi rtke','A','E','IC_cogs','814');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8700','rfolyamvesztesg','A','E','','870');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9110','Belfldi rbevtel','A','I','AR_amount:IC_sale:IC_income','911');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9111','Klfldi rbevtel','A','I','AR_amount:IC_sale:IC_income','911');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9700','rfolyamnyeresg','A','I','','970');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1','BEFEKTETETT ESZKZK','H','A','','1');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2','KSZLETEK','H','A','','2');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3','KVETELSEK','H','A','','3');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4','KTELEZETTSGEK','H','L','','4');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5','KLTSGEK','H','E','','5');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8','RFORDTSOK','H','E','','8');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9','BEVTELEK','H','I','','9');
--
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4660'),'0.25','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4661'),'0.15','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4662'),'0.05','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4663'),'0','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4670'),'0.25','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4671'),'0.15','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4672'),'0.05','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4673'),'0','');
--
UPDATE defaults SET inventory_accno_id = (SELECT id FROM chart WHERE accno = '2110'), income_accno_id = (SELECT id FROM chart WHERE accno = '9110'), expense_accno_id = (SELECT id FROM chart WHERE accno = '8140'), fxgain_accno_id = (SELECT id FROM chart WHERE accno = '9700'), fxloss_accno_id = (SELECT id FROM chart WHERE accno = '8700'), invnumber = 'sz1000' , sonumber = 'vr1000', ponumber = 'br1000', curr = 'HUF:EUR:USD', weightunit = 'kg';

==> sql-ledger_2.4.7.orig.tar.gz: sql-ledger/sql/Hungary-chart.sql <==
--Hungarian chart of accounts 
-- Magyar fknyvi szmlk, amelyek csak pldaknt szolglnak
--
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1140','Irodai eszkzk','A','A','','114');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1199','Irodai eszkzk CS','A','A','','119');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2610','ruk ','A','A','IC','261');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3110','Vevk','A','A','AR','311');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3111','Klfldi vevk','A','A','AR','311');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3810','Pnztr 1','A','A','AR_paid:AP_paid','381');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3811','Pnztr 2','A','A','AR_paid:AP_paid','381');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3840','Bank 1','A','A','AR_paid:AP_paid','384');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3841','Bank 2','A','A','AR_paid:AP_paid','384');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4540','Belfldi Szlltk','A','L','AP','454');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4541','Klfldi szlltk','A','L','AP','454');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4660','Visszaignyelhet FA 25%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4661','Visszaignyelhet FA 12%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4662','Visszaignyelhet FA 5%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4663','Visszaignyelhet FA admentes','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4670','Fizetend FA 25%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4671','Fizetend FA 15%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4672','Fizetend FA 5%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4673','Fizetend FA admentes','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5200','Brleti dj','A','E','AP_amount','520');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5210','Telefon','A','E','AP_amount','521');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5990','Kltsgek','A','E','IC_expense','599');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8140','Eladott ruk beszerzsi rtke','A','E','IC_cogs','814');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8700','rfolyamvesztesg','A','E','','870');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9110','Belfldi rbevtel','A','I','AR_amount:IC_sale:IC_income','911');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9111','Klfldi rbevtel','A','I','AR_amount:IC_sale:IC_income','911');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9700','rfolyamnyeresg','A','I','','970');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1','BEFEKTETETT ESZKZK','H','A','','1');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2','KSZLETEK','H','A','','2');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3','KVETELSEK','H','A','','3');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4','KTELEZETTSGEK','H','L','','4');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5','KLTSGEK','H','E','','5');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8','RFORDTSOK','H','E','','8');
INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('9','BEVTELEK','H','I','','9');
--
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4660'),'0.25','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4661'),'0.15','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4662'),'0.05','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4663'),'0','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4670'),'0.25','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4671'),'0.15','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4672'),'0.05','');
INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno='4673'),'0','');
--
UPDATE defaults SET inventory_accno_id = (SELECT id FROM chart WHERE accno = '2110'), income_accno_id = (SELECT id FROM chart WHERE accno = '9110'), expense_accno_id = (SELECT id FROM chart WHERE accno = '8140'), fxgain_accno_id = (SELECT id FROM chart WHERE accno = '9700'), fxloss_accno_id = (SELECT id FROM chart WHERE accno = '8700'), curr = 'HUF:EUR:USD', weightunit = 'kg';
